# Changelog

## 0.1.0-alpha.5 (2025-05-28)

Full Changelog: [v0.1.0-alpha.4...v0.1.0-alpha.5](https://github.com/octogen-systems/octogen-py-api/compare/v0.1.0-alpha.4...v0.1.0-alpha.5)

### Bug Fixes

* **docs/api:** remove references to nonexistent types ([61e4753](https://github.com/octogen-systems/octogen-py-api/commit/61e4753d0a0f03ca0822cd680e6a190afaae7206))


### Chores

* **ci:** fix installation instructions ([dd70d24](https://github.com/octogen-systems/octogen-py-api/commit/dd70d244ec1745fac96fb5e1b019b4f92f7c1edf))
* **docs:** grammar improvements ([0ed46e0](https://github.com/octogen-systems/octogen-py-api/commit/0ed46e03c3c4cbfaed4a172b601b15e893e349c6))
* **internal:** codegen related update ([88864d9](https://github.com/octogen-systems/octogen-py-api/commit/88864d9ff0fd1ec823df176bd38e83b186e490c7))

## 0.1.0-alpha.4 (2025-05-15)

Full Changelog: [v0.1.0-alpha.3...v0.1.0-alpha.4](https://github.com/octogen-systems/octogen-py-api/compare/v0.1.0-alpha.3...v0.1.0-alpha.4)

### Features

* **api:** update via SDK Studio ([f0bc80a](https://github.com/octogen-systems/octogen-py-api/commit/f0bc80a2b52e52d3800159fbde797c37910f66d0))

## 0.1.0-alpha.3 (2025-05-15)

Full Changelog: [v0.1.0-alpha.2...v0.1.0-alpha.3](https://github.com/octogen-systems/octogen-py-api/compare/v0.1.0-alpha.2...v0.1.0-alpha.3)

### Features

* **api:** update via SDK Studio ([16e55dd](https://github.com/octogen-systems/octogen-py-api/commit/16e55ddd23f68fcd3bb69f841ff431d8007ead4c))

## 0.1.0-alpha.2 (2025-05-15)

Full Changelog: [v0.1.0-alpha.1...v0.1.0-alpha.2](https://github.com/octogen-systems/octogen-py-api/compare/v0.1.0-alpha.1...v0.1.0-alpha.2)

### Features

* **api:** update via SDK Studio ([79894f7](https://github.com/octogen-systems/octogen-py-api/commit/79894f7c8cae4266867ad4b493d789668a48179c))


### Chores

* **ci:** upload sdks to package manager ([bf6eac2](https://github.com/octogen-systems/octogen-py-api/commit/bf6eac2ce4240871573b7cdeee91a1203d9e5ca7))

## 0.1.0-alpha.1 (2025-05-14)

Full Changelog: [v0.0.1-alpha.1...v0.1.0-alpha.1](https://github.com/octogen-systems/octogen-py-api/compare/v0.0.1-alpha.1...v0.1.0-alpha.1)

### Features

* **api:** update via SDK Studio ([313e76d](https://github.com/octogen-systems/octogen-py-api/commit/313e76d7dd31553efac2264b2ffbc1a8ec2383f1))

## 0.0.1-alpha.1 (2025-05-14)

Full Changelog: [v0.0.1-alpha.0...v0.0.1-alpha.1](https://github.com/octogen-systems/octogen-py-api/compare/v0.0.1-alpha.0...v0.0.1-alpha.1)

### Chores

* update SDK settings ([b062541](https://github.com/octogen-systems/octogen-py-api/commit/b062541cd48785c811d7917c785f8ecdff069fa9))
* update SDK settings ([5220f36](https://github.com/octogen-systems/octogen-py-api/commit/5220f3690b3054ac5a3bf8343e8f3f8797c89437))
